@@ -1,3 +1,4 @@
+import copy
 import curses
 import dataclasses
 import multiprocessing
@@ -146,7 +147,7 @@ class Reader:
                 self._process_counting_letter = multiprocessing.Process(
                     name="epy-subprocess-counting-letters",
                     target=count_letters_parallel,
-                    args=(self.ebook, self._proc_child),
+                    args=(copy.deepcopy(self.ebook), self._proc_child),
                 )
                 # forking will raise
                 # zlib.error: Error -3 while decompressing data: invalid distance too far back
